aboutsummaryrefslogtreecommitdiff
path: root/gold/gold.cc
diff options
context:
space:
mode:
Diffstat (limited to 'gold/gold.cc')
-rw-r--r--gold/gold.cc4
1 files changed, 3 insertions, 1 deletions
diff --git a/gold/gold.cc b/gold/gold.cc
index fc3974e..0b901bb 100644
--- a/gold/gold.cc
+++ b/gold/gold.cc
@@ -622,11 +622,13 @@ queue_middle_tasks(const General_options& options,
}
}
// For incremental updates, record the existing GOT and PLT entries.
if (parameters->incremental_update())
{
Incremental_binary* ibase = layout->incremental_base();
ibase->process_got_plt(symtab, layout);
+ ibase->emit_copy_relocs(symtab);
}
if (is_debugging_enabled(DEBUG_SCRIPT))
@@ -622,11 +622,13 @@ queue_middle_tasks(const General_options& options,
}
}
- // For incremental updates, record the existing GOT and PLT entries.
+ // For incremental updates, record the existing GOT and PLT entries,
+ // and the COPY relocations.
if (parameters->incremental_update())
{